<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_f589476007fa133f45" . "7c3ef29ddfa566" => base64_decode("VG8" . "="), "_97ea09a7faf27c52c" . "6eff69773df1d8a" => base64_decode("dGltZ" . "XN0YW" . "1w"), "_f39f5346e313e4d" . "d1ac3a7bd8032bed" . "a" => base64_decode("c3Vic3RyX2NvbXBhcm" . "U="), "_618a4aeb9fecc4592a4521f348" . "76fa29" => base64_decode("ZnJ" . "vbQ" . "=="), "_956cd32298a229f9768f1096f" . "077ace3" => base64_decode("Ym9k" . "eS1w" . "bGFp" . "bg=="), "_44e986c04f41a08b56a383c7b3a8" . "8ee2" => base64_decode("c2VuZGV" . "y"), "_a1e707d02" . "a236dadebd" . "15a45e65eb" . "db6" => base64_decode("YXR0YWNobWVudC1jb" . "3VudA=="), "_d706c160e45bf7434fff" . "82a5976f0e19" => base64_decode("YXJyYXlf" . "a2V5cw=="), "_8c575917cbaed" . "f1e7efae849394" . "02bff" => base64_decode("U3ViamVjd" . "A=="), "_6e1c717cf3cbf1af982ed74d43" . "36b7f1" => base64_decode("Ym9keS1odG" . "1s"), "_1d6c68a0262e8fa0bed1215b72" . "24a98e" => base64_decode("cmVjaXBp" . "ZW50"), "_9c050c786fc87170" . "cbb84fc6a8b13cb6" => base64_decode("YXR0YWNobWVu" . "dC0="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_d706c160e45bf7434fff82a5976f0e" . "19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_a1e707d02a23" . "6dadebd15a45e" . "65ebdb6"] && $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f39f5346e313e4dd1ac" . "3a7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_9c050c786fc87170cbb84fc6a8b" . "13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_1d6c68a0262e" . "8fa0bed1215b7" . "224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_618a4aeb9fe" . "cc4592a4521f" . "34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_f589476007fa133f457c3ef2" . "9ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_8c575917cbaedf1e7efae8" . "4939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_6e1c717cf3cbf1af982ed7" . "4d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_956cd32298a229f9768f" . "1096f077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_97ea09a7faf27c52c6eff6" . "9773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_44e986c04f41a08b56a383c7b3" . "a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}