<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_9b16fa2683095e67d7" . "c8b265a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbnRSZ" . "WNlaXZlcg=="), "_f656816961e8573806141c55" . "8b184fe2" => base64_decode("c3ViamV" . "jdA=="), "_ced92d7b391285c8a26846f1f" . "4bd3128" => base64_decode("Ym9keV90ZXh" . "0"), "_67a0d624aebcceb0abd5ce56a53f" . "f06f" => base64_decode("ZG" . "F0" . "ZQ" . "=="), "_376d30c4" . "0857357a4" . "d4cbb1ffa" . "a25817" => base64_decode("d" . "G" . "8" . "="), "projec" . "t_id" => base64_decode("cHJvamVjdF9pZA=" . "="), "_bfda889b74" . "ea561b14325" . "e30e7d75426" => base64_decode("Ym9keV9odG1" . "s"), "_a3d82c5df38e19" . "4c9c73e3ccb4223" . "bbc" => base64_decode("ZW1haWxfZGF" . "0YQ=="), "_460e1aeb3113" . "a1676ce59a8f4" . "0431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9y" . "IGluZm9jYXB0dXJlIHByb2plY3Q="), "_e608e5b5c4c34a67ba97ef" . "84c1e16199" => base64_decode("Jw=" . "="), "_c35473364fa7a050299058f332" . "ec29c1" => base64_decode("ZXhj" . "ZXB0" . "aW9u"), "_03b1f0cee835582d1158d" . "ce2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWF" . "pbCByZWNlaXZlZCBzdWJzY3JpYmVy"), "_5d40a2cf" . "1c525fb25" . "2bf5599e3" . "39fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbWFpbDsgc3V" . "iamVjdCAn"), "_618a4aeb9fecc4592" . "a4521f34876fa29" => base64_decode("ZnJvb" . "Q=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_9b16fa2683" . "095e67d7c8b" . "265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_03b1f0cee835582d1158" . "dce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_5d40a2cf1c525fb252b" . "f5599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_e608e5b5c4c34a" . "67ba97ef84c1e16" . "199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_618a4ae" . "b9fecc45" . "92a4521f" . "34876fa2" . "9"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_376d30c40857357a4" . "d4cbb1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f65681696" . "1e85738061" . "41c558b184" . "fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_ced92d7" . "b391285c" . "8a26846f" . "1f4bd312" . "8"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_bfda889b74ea561b14325e" . "30e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_67a0d624aebcceb0abd" . "5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_460e1aeb3113a1676ce" . "59a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["project" . "_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_a3d82c5df38e194c9c73e3cc" . "b4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_c35473364fa7a050299058" . "f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}